@@ -44,7 +44,7 @@ NSArray *g_fbShortNameArray = @[@"SNB", @"IVB", @"HSW", @"BDW", @"SKL", @"KBL",
 const uint32_t g_fbSandyBridge[] = { 0x00010000, 0x00020000, 0x00030010, 0x00030030, 0x00040000, 0xFFFFFFFF, 0xFFFFFFFF, 0x00030020, 0x00050000 };
 
 NSArray *g_framebufferFlagsArray = @[@"FBAvoidFastLinkTraining", @"FBFramebufferCommonMemory", @"FBFramebufferCompression", @"FBEnableSliceFeatures", @"FBDynamicFBCEnable", @"FBUseVideoTurbo", @"FBForcePowerAlwaysConnected", @"FBDisableHighBitrateMode2", @"FBBoostPixelFrequencyLimit", @"FBLimit4KSourceSize", @"FBAlternatePWMIncrement1", @"FBAlternatePWMIncrement2", @"FBDisableFeatureIPS", @"FBUnknownFlag_2000", @"FBAllowConnectorRecover", @"FBUnknownFlag_8000", @"FBUnknownFlag_10000", @"FBUnknownFlag_20000", @"FBDisableGFMPPFM", @"FBUnknownFlag_80000", @"FBUnknownFlag_100000", @"FBEnableDynamicCDCLK", @"FBUnknownFlag_400000", @"FBSupport5KSourceSize"];
-NSArray *g_connectorFlagsArray = @[@"CNAlterAppertureRequirements", @"CNUnknownFlag_2", @"CNUnknownFlag_4", @"CNConnectorAlwaysConnected", @"CNUnknownFlag_10", @"CNUnknownFlag_20", @"CNDisableBlitTranslationTable", @"CNUnknownFlag_80", @"CNUnknownFlag_100", @"CNUnknownFlag_200", @"CNUnknownFlag_400", @"CNUnknownFlag_800", @"CNUnknownFlag_1000", @"CNUnknownFlag_2000", @"CNUnknownFlag_4000", @"CNUnknownFlag_8000"];
+NSArray *g_connectorFlagsArray = @[@"CNAlterAppertureRequirements", @"CNUnknownFlag_2", @"CNUnknownFlag_4", @"CNConnectorAlwaysConnected", @"CNUnknownFlag_10", @"CNUnknownFlag_20", @"CNDisableBlitTranslationTable", @"CNUseMiscIoPowerWell", @"CNUsePowerWell2", @"CNUnknownFlag_200", @"CNUnknownFlag_400", @"CNUnknownFlag_800", @"CNUnknownFlag_1000", @"CNUnknownFlag_2000", @"CNUnknownFlag_4000", @"CNUnknownFlag_8000"];
 
 string stringFormat(const string fmt_str, ...)
 {
